==> qmmp_1.3.1.orig.tar.bz2: qmmp-1.3.1/src/plugins/General/trackchange/translations/trackchange_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Track Change Plugin Settings</source>
        <translation>Einstellungen Titeländerungsmodul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="32"/>
        <location filename="../settingsdialog.ui" line="42"/>
        <location filename="../settingsdialog.ui" line="52"/>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Command to run when Qmmp starts new track</source>
        <translation>Auszuführender Befehl, wenn Qmmp einen neuen Titel startet</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="83"/>
        <source>Command to run toward to end of a track</source>
        <translation>Gegen Ende des Titels auszuführender Befehl</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>Command to run when Qmmp reaches the end of the playlist</source>
        <translation>Auszuführender Befehl, wenn Qmmp das Ende der Wiedergabeliste erreicht</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="97"/>
        <source>Command to run when title changes (i.e. network streams title)</source>
        <translation>Auszuführender Befehl, wenn sich der Titel ändert (z.B. der Titel von Netzwerkstreams)</translation>
    </message>
</context>
<context>
    <name>TrackChangeFactory</name>
    <message>
        <location filename="../trackchangefactory.cpp" line="30"/>
        <source>Track Change Plugin</source>
        <translation>Titeländerungsmodul</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="50"/>
        <source>About Track Change Plugin</source>
        <translation>Über Titeländerungsmodul</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="51"/>
        <source>Qmmp Track Change Plugin</source>
        <translation>Qmmp Titeländerungsmodul</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="52"/>
        <source>This plugin executes external command when current track is changed</source>
        <translation>Dieses Modul führt einen externen Befehl aus, wenn der aktuelle Titel geändert wird</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Geschrieben von: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>

==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/General/trackchange/translations/trackchange_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Track Change Plugin Settings</source>
        <translation>Einstellungen Titeländerungsmodul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <location filename="../settingsdialog.ui" line="56"/>
        <location filename="../settingsdialog.ui" line="73"/>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Command to run when Qmmp starts new track</source>
        <translation>Auszuführender Befehl, wenn Qmmp einen neuen Titel startet</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="46"/>
        <source>Command to run toward to end of a track</source>
        <translation>Gegen Ende des Titels auszuführender Befehl</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Command to run when Qmmp reaches the end of the playlist</source>
        <translation>Auszuführender Befehl, wenn Qmmp das Ende der Wiedergabeliste erreicht</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="80"/>
        <source>Command to run when title changes (i.e. network streams title)</source>
        <translation>Auszuführender Befehl, wenn sich der Titel ändert (z.B. der Titel von Netzwerkstreams)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="97"/>
        <source>Command to run on application startup:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="104"/>
        <source>Command to run on application exit:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrackChangeFactory</name>
    <message>
        <location filename="../trackchangefactory.cpp" line="30"/>
        <source>Track Change Plugin</source>
        <translation>Titeländerungsmodul</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="50"/>
        <source>About Track Change Plugin</source>
        <translation>Über Titeländerungsmodul</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="51"/>
        <source>Qmmp Track Change Plugin</source>
        <translation>Qmmp Titeländerungsmodul</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="52"/>
        <source>This plugin executes external command when current track is changed</source>
        <translation>Dieses Modul führt einen externen Befehl aus, wenn der aktuelle Titel geändert wird</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Geschrieben von: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>
